function [] = calc_qc_map(inobj, m, str_m, show_input_mesh)
% calc_qc_map
% Calculate the discrete QC surface mapping for the input mesh 
% given in inobj, associated with the beltrami coefficient m.
% Print to the screen the input mesh, the dc flattened mesh, and 
% the discrete QC flattened mesh. 
% Write to out.obj the dqc flattened mesh as texture coordinates.
% Also add mtl syntax for out.mtl to be the texture.
% Input:
%   inobj : name of .obj file containing the input mesh
%   m            : function handle fr beltrami coefficient    


% read the input .obj file:
% f will be the connectivity
% v will be the coordinates 
[f, v] = loaddotobj(inobj);

% default output .obj filename
outobj = 'out.obj';

if (strcmp(show_input_mesh, 'true'))
    % show input mesh
    figure();
    title('Original mesh');
    patch('Vertices', v, 'Faces', f, 'FaceColor', [0.9 0.9 0.9]);
    axis equal;
    axis off;
    axis vis3d;
end

% number of vertices
nv = size(v, 1);

% calculate the reimann metric induced from R^3
% for the input mesh
edgelens = get_edgelens(f, v);

% calculate isothermal coordinates for v
z = dcflatten(f, nv, edgelens); 

% calculate auxiliary metric associated with beltrami
% coefficient m
[l_aux, mz] = calc_aux_metric(f, z, m, edgelens);

% show dcflat mesh
figure();
subplot(1,2,1);
title('Discrete-conformally flattened mesh');
patch('Vertices', z, 'Faces', f, 'FaceColor','interp','CData', mz);
axis off;
axis vis3d;

% calculate isothermal coordinates under new metric
 vt = dcflatten(f, nv, l_aux);

% show output mesh
subplot(1,2,2);
title(char(['Discrete Quasi-conformally flattened mesh, mu = ', str_m]));
patch('Vertices', vt, 'Faces', f, 'FaceColor','interp','CData', mz);
axis off;
axis vis3d;

nf = size(f, 1);
write_out_obj(outobj, v, vt, f, nv, nf);

end