function [f, v] = loaddotobj(objfile)
% LOADDOTOBJ load an Alias/Wavefront obj file
% Reads only vertex coordinates and face-vertex indices.
% Only triangular faces are allowed.
% Boris Springborn, TU Berlin, 2007

if nargin <1
    error('File name must be given as argument.')
end


% read the file and store the lines in a cell array of strings
objfile_and_path = char(['input_objs\', objfile]);
fid = fopen(objfile_and_path,'r');
if (fid<0)
    error(['Cannot open file ', objfile, '.']);
end
temp = textscan(fid, '%s', 'delimiter', '', 'commentstyle', 'shell');
fclose(fid);
thelines = temp{1};

% determine number of faces and vertices
fn = uint32(0);
vn = uint32(0);
for n = 1:size(thelines, 1)
    aline = thelines{n};
    switch aline(1)
        case 'f'
            fn = fn + 1;
        case 'v'
            if (aline(2) == ' ')
                vn = vn + 1;
            else if (aline(2) == 't')
                    if (aline(3) == ' ')
                        vn = vn + 1;
                    end
                end
            end
    end
end

f = zeros(fn, 3);
v = zeros(vn, 3);
    
fnum=uint32(0);
vnum=uint32(0);

% Line by line parsing of the obj file
for n = 1:size(thelines, 1);
    aline = thelines{n};
    switch aline(1)
        case '' % blank line
            % ignore
        case 'v' % vertex coords
            if (aline(2) == ' ')
                vnum = vnum + 1;
                v(vnum, :) = sscanf(aline(2:end), '%f', 3);
            else if (aline(2) == 't')
                    if (aline(3) == ' ')
                        vnum = vnum + 1;
                        values = sscanf(aline(3:end), '%f', 2);
                        v(vnum, 1) = values(1);
                        v(vnum, 2) = values(2);
                    end
                end
            end
        case 'f' % face indices
            fnum = fnum + 1;
            %% strip normal and texture indices
            %stripped = regexprep(aline(2:end), '/[0-9]*', '');
            %indexes = uint32(sscanf(stripped, '%d'));
            fields = textscan(aline(2:end), '%s');
            if (size(fields{1}, 1) ~= 3)
                error(['Mesh seems to contain a non-triangle face: ', aline]);
            end
            %f(1, fnum) = uint32(sscanf(fields{1}{1}, '%u', 1));
            %f(2, fnum) = uint32(sscanf(fields{1}{2}, '%u', 1));
            %f(3, fnum) = uint32(sscanf(fields{1}{3}, '%u', 1));
            i1 = textscan(fields{1}{1}, '%u', 1);
            i2 = textscan(fields{1}{2}, '%u', 1);
            i3 = textscan(fields{1}{3}, '%u', 1);
            f(fnum, :) = [i1{1}, i2{1}, i3{1}];
    end
end

if (fnum ~= fn)
    error('Assertion failure.');
end

if (vnum ~= vn)
    error('Assertion failure.');
end

end % of function loaddotobj